import { EVMBlockchainIncludingTestnet } from './evm.cjs';
export { EVMBlockchain, EVMBlockchainTestnet, EVM_BLOCKCHAINS_INCLUDING_TESTNETS, EVM_BLOCKCHAIN_TESTNETS, EVM_CHAINS } from './evm.cjs';
import { ObjectValues } from '../../types/utils.cjs';
export { BLOCKCHAIN_BASE_LAYERS, BlockchainBaseLayer } from './baseLayers.cjs';
export { Wallet } from './wallet.cjs';

interface EVMNFT {
    chain: EVMBlockchainIncludingTestnet;
    contractAddress: string;
    tokenId: string;
}
interface SolanaNFT {
    mintHash: string;
    chain: "solana";
}
interface CardanoNFT {
    chain: "cardano";
    assetId: string;
}
type NFTLocator<T extends Blockchain> = `${T}:${string}${T extends EVMBlockchainIncludingTestnet ? `:${string}` : ""}`;
type NFT = SolanaNFT | EVMNFT | CardanoNFT;
type NFTOrNFTLocator = NFT | NFTLocator<"solana"> | NFTLocator<"ethereum"> | NFTLocator<"polygon"> | NFTLocator<"bsc"> | NFTLocator<"cardano">;

declare const Blockchain: {
    readonly ETHEREUM: "ethereum";
    readonly POLYGON: "polygon";
    readonly BSC: "bsc";
    readonly OPTIMISM: "optimism";
    readonly ARBITRUM: "arbitrum";
    readonly BASE: "base";
    readonly ZORA: "zora";
    readonly ARBITRUMNOVA: "arbitrumnova";
    readonly ZKATANA: "zkatana";
    readonly ZKYOTO: "zkyoto";
    readonly ASTAR_ZKEVM: "astar-zkevm";
    readonly APEX: "apex";
    readonly SOLANA: "solana";
    readonly CARDANO: "cardano";
    readonly SUI: "sui";
    readonly APTOS: "aptos";
};
type Blockchain = ObjectValues<typeof Blockchain>;
declare const BLOCKCHAINS: readonly ("ethereum" | "polygon" | "bsc" | "optimism" | "arbitrum" | "base" | "zora" | "arbitrumnova" | "zkatana" | "zkyoto" | "astar-zkevm" | "apex" | "solana" | "cardano" | "sui" | "aptos")[];
declare const BlockchainTestnet: {
    readonly ARBITRUM_SEPOLIA: "arbitrum-sepolia";
    readonly BASE_GOERLI: "base-goerli";
    readonly BASE_SEPOLIA: "base-sepolia";
    readonly BSC_TESTNET: "bsc-testnet";
    readonly ETHEREUM_GOERLI: "ethereum-goerli";
    readonly ETHEREUM_SEPOLIA: "ethereum-sepolia";
    readonly POLYGON_MUMBAI: "polygon-mumbai";
    readonly POLYGON_AMOY: "polygon-amoy";
    readonly OPTIMISM_GOERLI: "optimism-goerli";
    readonly OPTIMISM_SEPOLIA: "optimism-sepolia";
    readonly ZORA_GOERLI: "zora-goerli";
    readonly ZORA_SEPOLIA: "zora-sepolia";
    readonly HYPERSONIC_TESTNET: "hypersonic-testnet";
};
type BlockchainTestnet = ObjectValues<typeof BlockchainTestnet>;
declare const BLOCKCHAIN_TESTNETS: readonly ("arbitrum-sepolia" | "base-goerli" | "base-sepolia" | "bsc-testnet" | "ethereum-goerli" | "ethereum-sepolia" | "polygon-mumbai" | "polygon-amoy" | "optimism-goerli" | "optimism-sepolia" | "zora-goerli" | "zora-sepolia" | "hypersonic-testnet")[];
declare const BlockchainIncludingTestnet: {
    readonly ARBITRUM_SEPOLIA: "arbitrum-sepolia";
    readonly BASE_GOERLI: "base-goerli";
    readonly BASE_SEPOLIA: "base-sepolia";
    readonly BSC_TESTNET: "bsc-testnet";
    readonly ETHEREUM_GOERLI: "ethereum-goerli";
    readonly ETHEREUM_SEPOLIA: "ethereum-sepolia";
    readonly POLYGON_MUMBAI: "polygon-mumbai";
    readonly POLYGON_AMOY: "polygon-amoy";
    readonly OPTIMISM_GOERLI: "optimism-goerli";
    readonly OPTIMISM_SEPOLIA: "optimism-sepolia";
    readonly ZORA_GOERLI: "zora-goerli";
    readonly ZORA_SEPOLIA: "zora-sepolia";
    readonly HYPERSONIC_TESTNET: "hypersonic-testnet";
    readonly ETHEREUM: "ethereum";
    readonly POLYGON: "polygon";
    readonly BSC: "bsc";
    readonly OPTIMISM: "optimism";
    readonly ARBITRUM: "arbitrum";
    readonly BASE: "base";
    readonly ZORA: "zora";
    readonly ARBITRUMNOVA: "arbitrumnova";
    readonly ZKATANA: "zkatana";
    readonly ZKYOTO: "zkyoto";
    readonly ASTAR_ZKEVM: "astar-zkevm";
    readonly APEX: "apex";
    readonly SOLANA: "solana";
    readonly CARDANO: "cardano";
    readonly SUI: "sui";
    readonly APTOS: "aptos";
};
type BlockchainIncludingTestnet = ObjectValues<typeof BlockchainIncludingTestnet>;
declare const BLOCKCHAINS_INCLUDING_TESTNETS: readonly ("ethereum" | "polygon" | "bsc" | "optimism" | "arbitrum" | "base" | "zora" | "arbitrumnova" | "zkatana" | "zkyoto" | "astar-zkevm" | "apex" | "arbitrum-sepolia" | "base-goerli" | "base-sepolia" | "bsc-testnet" | "ethereum-goerli" | "ethereum-sepolia" | "polygon-mumbai" | "polygon-amoy" | "optimism-goerli" | "optimism-sepolia" | "zora-goerli" | "zora-sepolia" | "hypersonic-testnet" | "solana" | "cardano" | "sui" | "aptos")[];

export { BLOCKCHAINS, BLOCKCHAINS_INCLUDING_TESTNETS, BLOCKCHAIN_TESTNETS, Blockchain, BlockchainIncludingTestnet, BlockchainTestnet, type CardanoNFT, EVMBlockchainIncludingTestnet, type EVMNFT, type NFT, type NFTLocator, type NFTOrNFTLocator, type SolanaNFT };
